@@ -3,6 +3,7 @@ from streamduo.api.health import Health
 from streamduo.api.stream import Stream
 from streamduo.api.actor import Actor
 from streamduo.api.record import RecordController
+from streamduo.api.user import User
 
 class Client:
     def __init__(self, client_id, client_secret):
@@ -30,16 +31,19 @@ class Client:
             self.token = None
 
 
-    def call_api(self, verb, path, body=None):
+    def call_api(self, verb, path, body=None, files=None):
         header = {'authorization': f"Bearer {self.token}",
                 'content-type': 'application/json'}
         if verb == 'GET':
             return requests.get(f"{self.api_endpoint}{path}",
                                 headers=header)
         if verb == 'POST':
+            if files:
+                del header['content-type']
             return requests.post(f"{self.api_endpoint}{path}",
-                                headers=header,
-                                json=body)
+                                 headers=header,
+                                 files=files,
+                                 json=body)
         if verb == 'DELETE':
             return requests.delete(f"{self.api_endpoint}{path}",
                                 headers=header,
@@ -56,3 +60,6 @@ class Client:
 
     def get_record_controller(self):
         return RecordController(self)
+
+    def get_user_controller(self):
+        return User(self)
